package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableDoubleConsumer.class */
public interface FailableDoubleConsumer<E extends Throwable> {
    public static final FailableDoubleConsumer NOP = t -> {
    };

    void accept(double d) throws Throwable;

    static <E extends Throwable> FailableDoubleConsumer<E> nop() {
        return NOP;
    }

    default FailableDoubleConsumer<E> andThen(FailableDoubleConsumer<E> after) {
        Objects.requireNonNull(after);
        return t -> {
            accept(t);
            after.accept(t);
        };
    }
}
